@@ -39,6 +39,7 @@ var log = getFromLocalStorage('log') || false;
 var cardsReady = false
 var cat = []
 var customJSN = new Object();
+var customTMP = new Object();
 
 
 var week = ["week_0","week_1","week_2","week_3","week_4","week_5","week_6"];
@@ -1545,6 +1546,15 @@ translatejs()
 UIkit.modal(modal).show();
 }
 
+/**
+ * The function `OpenModalEX` opens a modal with the specified `name` using UIkit.
+ * @param name - The `name` parameter in the `OpenModalEX` function is used to specify the ID of the
+ * modal that you want to open.
+ */
+function OpenModalEX(name){
+    UIkit.modal(`#${name}`).show();
+}
+
 var elem = document.documentElement;
 
 /**
